DNS_CONFIG_FILE="/etc/resolv.conf"

NTP_CONFIG_FILE="/etc/ntp.conf"
NTP_SERVICE_DAEMON="/etc/init.d/ntpd"


#########################################
# startNetwork
# Start the network interfaces
#
#########################################
startNetwork()
{
   LogTrace "Start network"
   RunCommand "/etc/init.d/networkingEth2 start"
}

#########################################
# stopNetwork
# Stop the network interface and DHCP
#
#########################################
stopNetwork()
{
   LogTrace "Stop network"
   RunCommand "/etc/init.d/networkingEth2 stop"
}

#########################################
# restartNetwork
# Restart the network interface
#
#########################################
restartNetwork()
{
   LogTrace "Restart network"
   RunCommand "/etc/init.d/networkingEth2 restart"
}

#########################################
# configureDNS
#
# update the dns resolution servers
#########################################
configureDNS()
{
    local dnsServers="$1"

    echo "##### Configured by services.sh #####" > $DNS_CONFIG_FILE
    for server in `echo $dnsServers`;
    do
        echo "nameserver ${server}" >> $DNS_CONFIG_FILE
    done
}

#########################################
# getDomainServers
#
# 
#########################################
getDomainServers()
{
    servers=`cat $DNS_CONFIG_FILE | grep "^nameserver" | awk '{print $2}'`
    if [ -z "$servers" ]; then
        echo "disabled"
    else
        echo $servers
    fi
}

#########################################
# configureNTP
#
# 
#########################################
configureNTP()
{
    ntpServers="$1"

    if [ "$ntpServers" = "disable" ]; then
        echo "##### Configured by servicesManager.sh #####" > $NTP_CONFIG_FILE
        echo "#server disabled iburst" >> $NTP_CONFIG_FILE
    else
        numServers=`echo $ntpServers | awk '{print NF}'`

        if [ ${numServers} -gt 0 ]; then
            echo "##### Configured by servicesManager.sh #####" > $NTP_CONFIG_FILE
            for server in `echo $ntpServers`;
            do
                echo "server ${server} iburst" >> $NTP_CONFIG_FILE
            done
        fi
    fi

    echo "
driftfile /etc/ntp.drift
keys /etc/ntp.keys
controlkey 1
requestkey 1
trustedkey 1
server 127.127.1.1
fudge  127.127.1.1 stratum 12
tinker panic 0
    " >> $NTP_CONFIG_FILE

    $NTP_SERVICE_DAEMON restart
}

#########################################
# getNTPServers
#
# 
#########################################
getNTPServers()
{
    servers=`cat $NTP_CONFIG_FILE | grep "^server .* iburst$" | awk '{print $2}'`
    if [ -z "$servers" ]; then
        echo "disabled"
    else
        echo $servers
    fi
}

